@@ -9,8 +9,8 @@ from google.oauth2.service_account import Credentials
 from trell.exceptions import BigQueryConnectionError, BigQueryDataFetchError, BigQueryGenericError
 
 from trell import config
-from trell.utils import LogFormatter
-LogFormatter.apply()
+# from trell.utils import LogFormatter
+# LogFormatter.apply()
 
 
 
@@ -129,7 +129,7 @@ class BigQuery:
         """
 
         try:
-            table = '{0}.{1}.{2}'.format(WRITE_BIG_QUERY_PROJECT, dataset, table)
+            table = '{0}.{1}.{2}'.format(self.WRITE_BIG_QUERY_PROJECT, dataset, table)
             rows_to_insert = rows_to_insert
             errors = self.bq_client.insert_rows_json(table, rows_to_insert)
             assert errors == []
