@@ -1,3 +1,6 @@
+class AwsConnectionError(Exception):
+    """Raised when data from aws connection is failed"""
+
 class BigQueryConnectionError(Exception):
     """Raised when data from bigQuery connection is failed"""
 
