@@ -49,13 +49,14 @@ def insert_rows_in_bigquery(dataset=None, table=None, rows_to_insert=None):
         logging.info(traceback.format_exc())
 
 
-def get_bigquery_data_from_query(query=None, max_retries=0, time_interval=5):
+def get_bigquery_data_from_query(query=None, query_config=None, max_retries=0, time_interval=5):
 
     flag = True
     while (flag):
         try:
             if query:
-                df = gbq.read_gbq(query=query, project_id=READ_BIG_QUERY_PROJECT, credentials=credentials)
+                df = gbq.read_gbq(query=query, project_id=READ_BIG_QUERY_PROJECT,
+                                  configuration=query_config, credentials=credentials)
                 return df
             else:
                 return "Query is None"
@@ -81,12 +82,12 @@ def dump_dataframe_to_bigquery_table(dataset=None, table=None, dataframe=None, m
         logging.info(traceback.format_exc())
 
 
-def execute_bigquery_query(query, max_retries=0, time_interval=5):
+def execute_bigquery_query(query, query_config=None, max_retries=0, time_interval=5):
     flag = True
     while flag:
         try:
-            query_job = bq_client.query(query)  # API request
-            query_job.result()  # Waits for statement to finish
+            query_job = bq_client.query(query, job_config=query_config)  # API request
+            query_job.result(timeout=900)  # Waits for statement to finish
             logging.info("Executed auery -- ", query)
             flag = False
         except requests.exceptions.Timeout:
